@@ -30,15 +30,16 @@
 package SNMP::Info::AdslLine;
 
 use strict;
+use warnings;
 use Exporter;
 use SNMP::Info;
 
 @SNMP::Info::AdslLine::ISA       = qw/SNMP::Info Exporter/;
 @SNMP::Info::AdslLine::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %MIBS %FUNCS %GLOBALS %MUNGE/;
+our ($VERSION, %MIBS, %FUNCS, %GLOBALS, %MUNGE);
 
-$VERSION = '3.65';
+$VERSION = '3.71';
 
 %MIBS = ( 'ADSL-LINE-MIB' => 'adslLineType' );
 
@@ -105,8 +106,6 @@ none.
 
 =back
 
-MIBs can be found at ftp://ftp.cisco.com/pub/mibs/v2/v2.tar.gz
-
 =head1 GLOBALS
 
 =over
