@@ -1,5 +1,4 @@
 # SNMP::Info::CiscoQOS
-# $Id$
 #
 # Copyright (c) 2005 Alexander Hartmaier
 # All rights reserved.
@@ -31,15 +30,16 @@
 package SNMP::Info::CiscoQOS;
 
 use strict;
+use warnings;
 use Exporter;
 use SNMP::Info;
 
 @SNMP::Info::CiscoQOS::ISA       = qw/SNMP::Info Exporter/;
 @SNMP::Info::CiscoQOS::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %MIBS %FUNCS %GLOBALS %MUNGE/;
+our ($VERSION, %MIBS, %FUNCS, %GLOBALS, %MUNGE);
 
-$VERSION = '3.65';
+$VERSION = '3.71';
 
 %MIBS = ( 'CISCO-CLASS-BASED-QOS-MIB' => 'cbQosIfIndex', );
 
@@ -118,8 +118,6 @@ none.
 
 =back
 
-MIBs can be found at ftp://ftp.cisco.com/pub/mibs/v2/v2.tar.gz
-
 =head1 GLOBALS
 
 =over
