@@ -30,13 +30,14 @@
 package SNMP::Info::IPv6;
 
 use strict;
+use warnings;
 use Exporter;
 use SNMP::Info;
 
 @SNMP::Info::IPv6::ISA       = qw/SNMP::Info Exporter/;
 @SNMP::Info::IPv6::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %MIBS %FUNCS %GLOBALS %MUNGE $METHOD/;
+our ($VERSION, %MIBS, %FUNCS, %GLOBALS, %MUNGE, $METHOD);
 
 use constant {
     IPMIB   => 1,
@@ -44,7 +45,7 @@ use constant {
     IPV6MIB => 3,
 };
 
-$VERSION = '3.65';
+$VERSION = '3.71';
 
 
 
@@ -479,7 +480,9 @@ none.
 =over
 
 =item F<IP-MIB>
+
 =item F<IPV6-MIB>
+
 =item F<CISCO-IETF-IP-MIB>
 
 =back
