@@ -1,5 +1,4 @@
 # SNMP::Info::Layer2::Baystack
-# $Id$
 #
 # Copyright (c) 2008 Max Baker changes from version 0.8 and beyond.
 # All rights reserved.
@@ -31,38 +30,38 @@
 package SNMP::Info::Layer2::Baystack;
 
 use strict;
+use warnings;
 use Exporter;
 use SNMP::Info::SONMP;
 use SNMP::Info::NortelStack;
 use SNMP::Info::RapidCity;
-use SNMP::Info::LLDP;
 use SNMP::Info::Layer3;
 
 @SNMP::Info::Layer2::Baystack::ISA
     = qw/SNMP::Info::SONMP SNMP::Info::NortelStack
-    SNMP::Info::RapidCity SNMP::Info::LLDP
+    SNMP::Info::RapidCity
     SNMP::Info::Layer3 Exporter/;
 @SNMP::Info::Layer2::Baystack::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %FUNCS %GLOBALS %MIBS %MUNGE/;
+our ($VERSION, %FUNCS, %GLOBALS, %MIBS, %MUNGE);
 
-$VERSION = '3.65';
+$VERSION = '3.71';
 
 %MIBS = (
-    %SNMP::Info::Layer3::MIBS,    %SNMP::Info::LLDP::MIBS,
+    %SNMP::Info::Layer3::MIBS,
     %SNMP::Info::RapidCity::MIBS, %SNMP::Info::NortelStack::MIBS,
     %SNMP::Info::SONMP::MIBS,
     'BAY-STACK-PETH-EXT-MIB' => 'bspePethPsePortExtMeasuredPower',
 );
 
 %GLOBALS = (
-    %SNMP::Info::Layer3::GLOBALS,    %SNMP::Info::LLDP::GLOBALS,
+    %SNMP::Info::Layer3::GLOBALS,
     %SNMP::Info::RapidCity::GLOBALS, %SNMP::Info::NortelStack::GLOBALS,
     %SNMP::Info::SONMP::GLOBALS,
 );
 
 %FUNCS = (
-    %SNMP::Info::Layer3::FUNCS,    %SNMP::Info::LLDP::FUNCS,
+    %SNMP::Info::Layer3::FUNCS,
     %SNMP::Info::RapidCity::FUNCS, %SNMP::Info::NortelStack::FUNCS,
     %SNMP::Info::SONMP::FUNCS,
     'peth_port_power' => 'bspePethPsePortExtMeasuredPower',
@@ -74,7 +73,7 @@ $SNMP::Info::SPEED_MAP{200_000_000}   = '100 Mbps';
 $SNMP::Info::SPEED_MAP{2_000_000_000} = '1.0 Gbps';
 
 %MUNGE = (
-    %SNMP::Info::Layer3::MUNGE,    %SNMP::Info::LLDP::MUNGE,
+    %SNMP::Info::Layer3::MUNGE,
     %SNMP::Info::RapidCity::MUNGE, %SNMP::Info::NortelStack::MUNGE,
     %SNMP::Info::SONMP::MUNGE,
 );
@@ -429,11 +428,6 @@ Provides abstraction to the configuration information obtainable from an
 Avaya Ethernet Switch (formerly Nortel/Bay Baystack) and VSP 7000 series
 through SNMP.
 
-For speed or debugging purposes you can call the subclass directly, but not
-after determining a more specific class using the method above.
-
-my $baystack = new SNMP::Info::Layer2::Baystack(...);
-
 =head2 Inherited Classes
 
 =over
@@ -444,8 +438,6 @@ my $baystack = new SNMP::Info::Layer2::Baystack(...);
 
 =item SNMP::Info::RapidCity
 
-=item SNMP::Info::LLDP
-
 =item SNMP::Info::Layer3
 
 =back
@@ -454,7 +446,7 @@ my $baystack = new SNMP::Info::Layer2::Baystack(...);
 
 =over
 
-=item F<BAY-STACK-PETH-EXT-MIBB>
+=item F<BAY-STACK-PETH-EXT-MIB>
 
 =back
 
@@ -466,8 +458,6 @@ See L<SNMP::Info::NortelStack/"Required MIBs"> for its MIB requirements.
 
 See L<SNMP::Info::RapidCity/"Required MIBs"> for its MIB requirements.
 
-See L<SNMP::Info::LLDP/"Required MIBs"> for its MIB requirements.
-
 See L<SNMP::Info::Layer3/"Required MIBs"> for its MIB requirements.
 
 =head1 GLOBALS
@@ -537,10 +527,6 @@ See L<SNMP::Info::NortelStack/"GLOBALS"> for details.
 
 See L<SNMP::Info::RapidCity/"GLOBALS"> for details.
 
-=head2 Globals imported from SNMP::Info::LLDP
-
-See documentation in L<SNMP::Info::LLDP/"GLOBALS"> for details.
-
 =head2 Globals imported from SNMP::Info::Layer3
 
 See L<SNMP::Info::Layer3/"GLOBALS"> for details.
@@ -700,10 +686,6 @@ See L<SNMP::Info::NortelStack/"TABLE METHODS"> for details.
 
 See L<SNMP::Info::RapidCity/"TABLE METHODS"> for details.
 
-=head2 Table Methods imported from SNMP::Info::LLDP
-
-See documentation in L<SNMP::Info::LLDP/"TABLE METHODS"> for details.
-
 =head2 Table Methods imported from SNMP::Info::Layer3
 
 See L<SNMP::Info::Layer3/"TABLE METHODS"> for details.
