@@ -1,5 +1,4 @@
 # SNMP::Info::Layer2::NAP222x
-# $Id$
 #
 # Copyright (c) 2008 Eric Miller
 # All rights reserved.
@@ -31,6 +30,7 @@
 package SNMP::Info::Layer2::NAP222x;
 
 use strict;
+use warnings;
 use Exporter;
 use SNMP::Info::SONMP;
 use SNMP::Info::IEEE802dot11;
@@ -40,9 +40,9 @@ use SNMP::Info::Layer2;
     = qw/SNMP::Info::SONMP SNMP::Info::IEEE802dot11 SNMP::Info::Layer2 Exporter/;
 @SNMP::Info::Layer2::NAP222x::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %FUNCS %GLOBALS %MIBS %MUNGE/;
+our ($VERSION, %FUNCS, %GLOBALS, %MIBS, %MUNGE);
 
-$VERSION = '3.65';
+$VERSION = '3.71';
 
 %MIBS = (
     %SNMP::Info::Layer2::MIBS, %SNMP::Info::IEEE802dot11::MIBS,
@@ -393,11 +393,6 @@ Eric Miller
 Provides abstraction to the configuration information obtainable from a Nortel
 2220 series wireless Access Points through SNMP.
 
-For speed or debugging purposes you can call the subclass directly, but not
-after determining a more specific class using the method above.
-
- my $nap222x = new SNMP::Info::Layer2::NAP222x(...);
-
 =head2 Inherited Classes
 
 =over
