@@ -29,6 +29,7 @@
 package SNMP::Info::Layer2::Ubiquiti;
 
 use strict;
+use warnings;
 use Exporter;
 use SNMP::Info::IEEE802dot11;
 use SNMP::Info::Layer2;
@@ -40,23 +41,23 @@ use SNMP::Info::Layer3;  # only used in sub mac()
     = qw/SNMP::Info::IEEE802dot11 SNMP::Info::Layer2 Exporter/;
 @SNMP::Info::Layer2::Ubiquiti::EXPORT_OK = qw//;
 
-use vars qw/$VERSION %FUNCS %GLOBALS %MIBS %MUNGE/;
+our ($VERSION, %FUNCS, %GLOBALS, %MIBS, %MUNGE);
 
-$VERSION = '3.65';
+$VERSION = '3.71';
 
 %MIBS = (
     %SNMP::Info::Layer2::MIBS,
     %SNMP::Info::IEEE802dot11::MIBS,
-
 );
 
-%GLOBALS
-    = ( %SNMP::Info::Layer2::GLOBALS, %SNMP::Info::IEEE802dot11::GLOBALS, );
+%GLOBALS = (
+  %SNMP::Info::Layer2::GLOBALS,
+  %SNMP::Info::IEEE802dot11::GLOBALS,
+);
 
 %FUNCS = (
     %SNMP::Info::Layer2::FUNCS,
     %SNMP::Info::IEEE802dot11::FUNCS,
-
 );
 
 %MUNGE = ( %SNMP::Info::Layer2::MUNGE, %SNMP::Info::IEEE802dot11::MUNGE, );
@@ -70,14 +71,14 @@ sub os {
         my $prod = $names->{$iid};
         next unless defined $prod;
         # Product names that match AirOS products
-                if((lc $prod) =~ /station/ or (lc $prod) =~ /beam/ or (lc $prod) =~ /grid/){
-                        return 'AirOS';
-                # Product names that match UAP
-                }elsif((lc $prod) =~ /uap/){
-                        return 'UniFi';
-                }else{
-                    # Continue below to find OS name
-                }
+        if((lc $prod) =~ /station/ or (lc $prod) =~ /beam/ or (lc $prod) =~ /grid/){
+                return 'AirOS';
+        # Product names that match UAP
+        }elsif((lc $prod) =~ /uap/){
+                return 'UniFi';
+        }else{
+            # Continue below to find OS name
+        }
     }
 
     ## EdgeMAX OS (EdgeSwitch and EdgeRouter) name is first field split by space
@@ -89,35 +90,54 @@ sub os {
 }
 
 sub os_ver {
-    my $dot11 = shift;
+    my $ubnt = shift;
 
-    my $versions = $dot11->dot11_prod_ver();
+    my $versions = $ubnt->dot11_prod_ver();
 
     foreach my $iid ( keys %$versions ) {
         my $ver = $versions->{$iid};
         next unless defined $ver;
+        my $os = $ubnt->os;
+        if($os == 'AirOS'){
+            ## pretty up the version reporting for AirOS to include hardware (XW, XM, etc) and three major groups of firmware
+            my @firmware =  split(/v/, $ver);
+            my @firmwareSplit = split(/\./, $firmware[1]);
+            my @prefix = split(/\./, $ver);
+            $ver = $prefix[0] . '-v' . join('.', @firmwareSplit[0,1,2]);
+        }
         return $ver;
         ## Not sure what this function does, it seems to be extraneous being in the same code block after a return statement?
-        if ( $ver =~ /([\d\.]+)/ ) {
-            return $1;
-        }
+        #if ( $ver =~ /([\d\.]+)/ ) {
+        #    return $1;
+        #}
     }
-    my $ver = $dot11->description() || '';
-    if($ver =~ /^edgeswitch/){
-        ## EdgeSwitch OS version is second field split by comma
-        my @myver = split(/, /, $ver);
 
-        return $myver[1];
+    my $ver = $ubnt->description() || '';
+    if((lc $ver) =~ /^edgeswitch/){
+        ## EdgeSwitch OS version is second field split by comma and bootcode version is last
+        my @myver = split(/, /, $ver);
+        my @firmware = split(/\./, $myver[1]);
+        my @bootcode = split(/\./, $myver[-1]);
+
+        ## Return only three major version groupings and include bootcode version
+        return join('.', @firmware[0,1,2]) . '.-b' . join('.', @bootcode[0,1,2]);
+
     }
 
     ## EdgeRouter OS version is second field split by space
     my @myver = split(/ /, $ver);
+    my @firmware = split(/\./, $myver[1]);
 
-    return $myver[1];
+    if($firmware[2] =~ /hotfix$/){
+        # edge case where EdgeOS has hotfix versions in format "EdgeOS v1.9.7+hotfix.4.5024004.171005.0403"
+        $firmware[2] = $firmware[2] . '.' . $firmware[3]
+    }
+    ## Return only three major version groupings
+    return join('.', @firmware[0,1,2]);
 }
 
 sub vendor {
-    return 'Ubiquiti Networks, Inc.';
+    return 'ubiquiti';
 }
 
 sub model {
@@ -142,7 +162,7 @@ sub model {
     if(!((lc $desc) =~ /edgeos/)){
         # Not sure what type of device this is to get Model
         # Wireless devices report dot11_prod_name
-        # EdgeSwitch includes mode directly and edgeos logic is in else statement
+        # EdgeSwitch includes model directly and edgeos logic is in else statement
         return ;
     }else{
         ## do some logic to determine ER model based on tech specs from ubnt:
@@ -179,6 +199,9 @@ sub model {
         }if($ethCount eq 8){
             ## Could be ER-8 Pro, ER-8, or EP-R8
             return "EdgeRouter 8-Port"
+        }if($ethCount eq 12){
+            ## ER-12
+            return "EdgeRouter 12-Port"
         }elsif($ethCount eq 5 and $cpuCount eq 4){
             ## Could be ER-X or ER-X-SFP
             return "EdgeRouter X 5-Port"
@@ -210,13 +233,14 @@ sub serial {
 sub mac {
     my $ubnt = shift;
     my $ifDescs = $ubnt->ifDescr;
+    my $erModel = $ubnt->model;
 
     foreach my $iid ( keys %$ifDescs ) {
         my $ifDesc = $ifDescs->{$iid};
         next unless defined $ifDesc;
         ## CPU Interface will have the primary MAC for EdgeSwitch
-        ## eth0 will have primary MAC for linux-based UBNT devices
-        if($ifDesc =~ /CPU/ or $ifDesc eq 'eth0'){
+        ## eth0 will have primary MAC for linux-based UBNT devices, except ER-12 which is eth11
+        if($ifDesc =~ /CPU/ or ($ifDesc eq 'eth0' and !($erModel =~ /EdgeRouter 12/)) or ($ifDesc eq 'eth11' and ($erModel =~ /EdgeRouter 12/))){
             my $mac = $ubnt->ifPhysAddress->{$iid};
 
             # syntax stolen from sub munge_mac in SNMP::Info
@@ -230,11 +254,11 @@ sub mac {
 }
 
 sub interfaces {
-    my $netgear = shift;
+    my $ubnt = shift;
     my $partial = shift;
 
-    my $interfaces = $netgear->i_index($partial)       || {};
-    my $i_descr    = $netgear->i_description($partial) || {};
+    my $interfaces = $ubnt->i_index($partial)       || {};
+    my $i_descr    = $ubnt->i_description($partial) || {};
     my $return = {};
 
     foreach my $iid ( keys %$i_descr ) {
@@ -304,11 +328,6 @@ Max Kosmach
 Provides abstraction to the configuration information obtainable from
 Ubiquiti Access Point through SNMP.
 
-For speed or debugging purposes you can call the subclass directly, but not
-after determining a more specific class using the method above.
-
- my $ubnt = new SNMP::Info::Layer2::Ubiquiti(...);
-
 =head2 Inherited Classes
 
 =over
@@ -337,11 +356,11 @@ These are methods that return scalar value from SNMP
 
 =item $ubnt->vendor()
 
-Returns 'Ubiquiti Networks, Inc.'
+Returns 'ubiquiti'
 
 =item $ubnt->model()
 
-Returns the model extracted from C<dot11manufacturerProductName>, with failback to some complex logic for EdgeMax devices
+Returns the model extracted from C<dot11manufacturerProductName>, with fallback to some complex logic for EdgeMax devices
 
 =item $ubnt->serial()
 
@@ -353,11 +372,11 @@ Bridge MAC address.
 
 =item $ubnt->os()
 
-Returns 'Ubiquiti Networks, Inc.'
+Returns C<AirOS>, C<UniFi> or C<EdgeOS> depending on model.
 
 =item $ubnt->os_ver()
 
-Returns the software version extracted from C<dot11manufacturerProductVersion>, with failback to description splitting for EdgeMax devices
+Returns the software version extracted from C<dot11manufacturerProductVersion>, with fallback to description splitting for EdgeMax devices
 
 =back
 
@@ -378,11 +397,11 @@ to a hash.
 
 =over
 
-=item $ubiquiti->interfaces()
+=item $ubnt->interfaces()
 
 Uses the i_name() field.
 
-=item $ubiquiti->i_ignore()
+=item $ubnt->i_ignore()
 
 Ignores interfaces with "CPU Interface" in them.
 
